{% load i18n %}

{% if icon %}
    <a  href="{% url "admin:index" %}">
        <img src="{{ icon }}" class="h-8 mr-4" alt="{% trans "Home" %}"/>
    </a>
{% else %}
    <a href="{% url "admin:index" %}" class="bg-primary-600 flex h-8 items-center justify-center rounded-md mr-4 text-white text-xs w-8">
        <span class="material-symbols-outlined md-18">{% if symbol %}{{ symbol }}{% else %}settings{% endif %}</span>
    </a>
{% endif %}
